@@ -18,6 +18,7 @@ from sqlalchemy import event
 from sqlalchemy import Column, ForeignKey, Table
 from sqlalchemy import Boolean, Integer, Unicode
 from sqlalchemy.orm import relationship
+from sqlalchemy.schema import UniqueConstraint
 
 from zope.interface import implements
 
@@ -224,8 +225,11 @@ class Email(Base, BaseMixin):
     implements(IEmail)
 
     __tablename__ = 'auth_emails'
+    __table_args__ = (
+        UniqueConstraint('address', 'user_id', name='auth_user_email_address_uc'),
+    )
 
-    address = Column(Unicode(255), unique=True)
+    address = Column(Unicode(255))
 
     confirmation_hash = Column(Unicode(28), default=generate_confirmation_hash)
     is_confirmed = Column(Boolean, default=False)
@@ -262,7 +266,7 @@ def get_existing_user(cls=User, **kwargs):
     return query.first()
 
 
-def get_existing_email(address, cls=Email):
+def get_existing_email(address, user_id=None, cls=Email):
     """Get an existing email from the ``address`` provided.
 
       Setup::
@@ -279,10 +283,20 @@ def get_existing_email(address, cls=Email):
           'email1'
           >>> mock_cls.query.filter_by.assert_called_with(
           ...         address='foo@bar.com')
-
+      
+      Optionally filtering also by the user_id::
+      
+          >>> get_existing_email('foo@bar.com', user_id=1234, cls=mock_cls)
+          'email1'
+          >>> mock_cls.query.filter_by.assert_called_with(
+          ...         address='foo@bar.com', user_id=1234)
+      
     """
-
-    query = cls.query.filter_by(address=address)
+    
+    filter_kwargs = {'address': address}
+    if user_id is not None:
+        filter_kwargs['user_id'] = user_id
+    query = cls.query.filter_by(**filter_kwargs)
     return query.first()
 
 
